@@ -6,7 +6,7 @@ use strict;
 
 
 if($#ARGV<0){
-   die "Usage: $0 <file with paired sequences arranged consecutively>\n";
+   die "Usage: $0 <file with paired sequences>\n";
 }
 
 my $file = $ARGV[0];
@@ -29,7 +29,7 @@ while(<IN>){
       $template = $1;
       $read = $1 . $2;
 
-      print "$ptemplate $template .. $read\n";
+#      print "$ptemplate $template .. $read\n";
 
       if($template ne $ptemplate && $ptemplate ne ""){
 
